@@ -1,6 +1,5 @@
 from sqlalchemy.ext.asyncio import create_async_engine
 from sqlalchemy.ext.asyncio import AsyncConnection
-from sqlalchemy.pool import QueuePool
 from .logger_config import logger
 from dotenv import dotenv_values
 from threading import Lock
@@ -119,7 +118,7 @@ class EngineManager:
                     try:
                         connection_string = _build_connection_string(db_type, env)
                         logger.info(f"Creating engine for {db_type}...")
-                        self._engines[env_file] = create_async_engine(connection_string, poolclass = QueuePool, pool_size = 30, max_overflow = 20, pool_recycle = 1800, pool_timeout = 90)
+                        self._engines[env_file] = create_async_engine(connection_string, pool_size = 10, max_overflow = 20, pool_recycle = 1800, pool_timeout = 90)
                     except KeyError as e:
                         logger.error(f"Error: {e}")
                         raise
