@@ -5,6 +5,7 @@ from sqlalchemy import text
 import pandas as pd
 import sqlalchemy
 import aiofiles
+import inspect
 import asyncio
 import os
 
@@ -21,7 +22,10 @@ engine_manager = EngineManager()
     """
 async def format_to_df(query_output):
     try:
-        rows = await query_output.fetchall()
+        if inspect.iscoroutinefunction(query_output.fetchall):
+            rows = await query_output.fetchall()
+        else:
+            rows = query_output.fetchall()
         columns_name = query_output.keys()
         return pd.DataFrame(rows, columns=columns_name)
     except Exception as e:
@@ -44,7 +48,7 @@ async def _execute_db_query_or_procedure(query_or_procedure , table_to_backup, e
     kind = "query" if is_query else "procedure"
     conn = None
     try:
-        conn = await engine_manager.connect_db(env_file_name)
+        conn = await engine_manager.get_db_connection(env_file_name)
         await backup_table(table_to_backup, conn)
 
         if not is_query:
@@ -57,6 +61,7 @@ async def _execute_db_query_or_procedure(query_or_procedure , table_to_backup, e
         if not output.returns_rows:
             return None
         return await format_to_df(output)
+
     except sqlalchemy.exc.SQLAlchemyError as e:
         error_message = f"Failed to execute {kind}:\n{e}"
         logger.error(error_message)
@@ -133,7 +138,10 @@ async def backup_table(table_to_backup , conn):
 
         backup_query = f"SELECT * FROM {table_to_backup}"
         result = await conn.execute(text(backup_query))
-        rows = result.fetchall()
+        if inspect.iscoroutinefunction(result.fetchall):
+            rows = await result.fetchall()
+        else:
+            rows = result.fetchall()
         columns = result.keys()
         backup_df = pd.DataFrame(rows, columns=columns)
         backup_filename = os.path.join(backup_dir_name, f"{table_to_backup}_backup_{datetime.now().strftime('%Y-%m-%d_%H-%M-%S')}.md")
@@ -162,19 +170,20 @@ async def backup_table(table_to_backup , conn):
         ValueError: If the file is empty.
         IOError: If there is an issue reading the file or executing the query.
     """
-def get_query_from_file(file_path, table_to_backup, env_file_name=None, params=None):
+async def get_query_from_file(file_path, table_to_backup, env_file_name=None, params=None):
     if not os.path.exists(file_path):
         error_message = f"File '{file_path}' not found."
         logger.error(error_message)
         raise FileNotFoundError(error_message)
     try:
-        with open(file_path, "r", encoding="utf-8") as file:
-            query = file.read().strip()
+        async with aiofiles.open(file_path, "r", encoding="utf-8") as file:
+            query = await file.read()
+            query = query.strip()
             if not query:
                 error_message = f"The file '{file_path}' is empty."
                 logger.error(error_message)
                 raise ValueError(error_message)
-            return asyncio.run(get_query_from_db(query, table_to_backup , env_file_name , params))
+            return await get_query_from_db(query, table_to_backup, env_file_name, params)
     except ValueError:  # Handle explicit empty file exception
         raise
     except Exception as e:
